"""
    schemas: vehicle-specific decoded status message (DRAFT ONLY)
"""
from flask_restx import Api, fields
from flask import Flask

app = Flask(__name__)
api = Api(app)

vehicle_status_message_schema = api.model(
    "VehicleStatusMessage",
    {
        "message_source": fields.String(
            required=True,
            description="Where is this message from",
            example="autonomy_engine",
        ),
        "message_destination": fields.String(
            required=True,
            description="What is the destination of this message",
            example="ah-1",
        ),
        "encoded": fields.Boolean(
            required=True,
            description="Is this message encoded (encoded=True, decoded=False)",
            example=False,
        ),
        "serial_number": fields.String(
            required=True,
            description="vehicle serial number",
            example="ah-1",
        ),
        "time": fields.String(
            required=True,
            description="Timestamp of message",
            example="2022-11-16T00:00:00Z",
        ),
        "version": fields.Integer(
            required=True,
            description="", # we can track the version of the AE plan?
            example="",
        ),
        "platform_ID": fields.Integer(
            required=True,
            description="Platform ID",
            example=2,
        ),
        "platform_type": fields.String(
            required=True,
            description="The high level type of this vehicle",
            example="alr",
        ),
        "platform_state": fields.String(
            required=True,
            description="",
            example="SAFETY_STOP",
        ),
        "current_mission_state": fields.String(
            required=True,
            description="",
            example="",
        ),
        "gps_source": fields.Float(
            required=True,
            description="",
            example="",
        ),
        "gps_lat": fields.Float(
            required=True,
            description="",
            example="",
        ),
        "gps_lon": fields.Float(
            required=True,
            description="",
            example="",
        ),
        "gps_fix_seconds_ago": fields.String(
            required=True,
            description="",
            example="",
        ),
    },
)
